@@ -362,6 +362,10 @@ bool parseVisual(Visual &vis, TiXmlElement *config)
   if (!vis.geometry)
     return false;
 
+  const char *name_char = config->Attribute("name");
+  if (name_char)
+    vis.name = name_char;
+
   // Material
   TiXmlElement *mat = config->FirstChildElement("material");
   if (mat) {
@@ -376,15 +380,10 @@ bool parseVisual(Visual &vis, TiXmlElement *config)
     vis.material.reset(new Material());
     if (!parseMaterial(*vis.material, mat, true))
     {
-      logDebug("material has only name, actual material definition may be in the model");
+      logDebug("urdfdom: material has only name, actual material definition may be in the model");
     }
   }
   
-  vis.group_name = std::string("default");
-  const char *group_name_char = config->Attribute("group");
-  if (group_name_char)
-    logWarn("The notion of a group name for visual tags is not supported by URDF.");
-  
   return true;
 }
 
@@ -405,10 +404,9 @@ bool parseCollision(Collision &col, TiXmlElement* config)
   if (!col.geometry)
     return false;
 
-  col.group_name = std::string("default");
-  const char *group_name_char = config->Attribute("group");
-  if (group_name_char)
-    logWarn("The notion of a group name for collision tags is not supported by URDF.");
+  const char *name_char = config->Attribute("name");
+  if (name_char)
+    col.name = name_char;
 
   return true;
 }
@@ -439,8 +437,6 @@ bool parseLink(Link &link, TiXmlElement* config)
   }
 
   // Multiple Visuals (optional)
-  // For backward compatibility, we fill the map from group_name to visual tag (for ROS Groovy);
-  // Please use the visual_array instead
   for (TiXmlElement* vis_xml = config->FirstChildElement("visual"); vis_xml; vis_xml = vis_xml->NextSiblingElement("visual"))
   {
 
@@ -448,18 +444,6 @@ bool parseLink(Link &link, TiXmlElement* config)
     vis.reset(new Visual());
     if (parseVisual(*vis, vis_xml))
     {
-      boost::shared_ptr<std::vector<boost::shared_ptr<Visual > > > viss = link.getVisuals(vis->group_name);
-      if (!viss)
-      {
-        // group does not exist, create one and add to map
-        viss.reset(new std::vector<boost::shared_ptr<Visual > >);
-        // new group name, create vector, add vector to map and add Visual to the vector
-        link.visual_groups.insert(make_pair(vis->group_name,viss));
-      }
-      
-      // group exists, add Visual to the vector in the map
-      viss->push_back(vis);
-
       link.visual_array.push_back(vis);
     }
     else
@@ -476,26 +460,12 @@ bool parseLink(Link &link, TiXmlElement* config)
     link.visual = link.visual_array[0];
   
   // Multiple Collisions (optional)
-  // For backward compatibility, we fill the map from group_name to collision tag (for ROS Groovy);
-  // Please use the collision_array instead
   for (TiXmlElement* col_xml = config->FirstChildElement("collision"); col_xml; col_xml = col_xml->NextSiblingElement("collision"))
   {
     boost::shared_ptr<Collision> col;
     col.reset(new Collision());
     if (parseCollision(*col, col_xml))
     {      
-      boost::shared_ptr<std::vector<boost::shared_ptr<Collision > > > cols = link.getCollisions(col->group_name);  
-      
-      if (!cols)
-      {
-        // group does not exist, create one and add to map
-        cols.reset(new std::vector<boost::shared_ptr<Collision > >);
-        // new group name, create vector, add vector to map and add Collision to the vector
-        link.collision_groups.insert(make_pair(col->group_name,cols));
-      }
-
-      // group exists, add Collision to the vector in the map
-      cols->push_back(col);
       link.collision_array.push_back(col);
     }
     else
